@@ -11,7 +11,7 @@ import yaml
 class Home():
     def __init__(self):
         print(
-            '\nWelcome to SIGACTor 0.1.11dev, currently available '
+            '\nWelcome to SIGACTor 0.1.16dev, currently available '
             'for the Syria team and reading posts from the '
             "Syrian Observatory for Human Rights' Facebook Page."
         )
@@ -35,7 +35,7 @@ class Home():
             'Country Team',
             'Date Begin',
             'Date End',
-			'Posted Date',
+            'Posted Date',
         ]
 
         print('\nPreparing CSV...')
@@ -78,26 +78,23 @@ class Home():
 
         while True:
             self.entered_date = input(
-                '\nPlease enter a starting time. '
-                '(YYYY-MM-DD-hhmm, or enter "m" to manually enter an activity) '
+                '\nPlease enter a starting time. (YYYY-MM-DD-hhmm,'
+                'or enter "m" to manually enter an activity) '
             )
 
             if self.entered_date == 'm':
                 self.activities.append(ManualActivity(self))
                 continue
-            
+
             self.entered_date += (
                 datetime.now(dateutil.tz.tzlocal()).strftime('%z')
             )
 
             try:
-                self.start_date = datetime.strptime(
-                    self.entered_date, '%Y-%m-%d-%H%M%z'
-                )
+                self.start_date = datetime.strptime(self.entered_date, '%Y-%m-%d-%H%M%z')
                 break
             except ValueError:
                 print('Invalid date. ')
-                self.entered_date = input_date()
                 continue
 
         self.stop = False
